@@ -79,7 +79,7 @@ rps = [
      r'\n.SE\n.SH "TYPE"\n\1\n'
      r'\n.SE\n.SH "SYNOPSIS"\n\3\n'
      r'\n.SE\n.SH "DESCRIPTION"\n' % datetime.date.today(), re.S),
-    (r'<span class="C_ico cpp11warning"[^>]*>', r' [C++11]', re.S),
+    (r'<span alt="[^"]*?" class="C_ico cpp11warning"[^>]*>', r' [C++11]', re.S),
     # Remove empty #include
     (r'#include \n.sp\n', r'', 0),
     # Remove empty sections
@@ -94,25 +94,25 @@ rps = [
     # 'pre' tag
     (r'<pre[^>]*>(.+?)</pre\s*>', r'\n.nf\n\1\n.fi\n', re.S),
     # Subsections
-    (r'<b>(.+?)</b>:<br>', r'.SS \1\n', 0),
+    (r'<b>(.+?)</b>:<br/>', r'.SS \1\n', 0),
     # Member functions / See Also table
-    # # Without C++11 tag
-    (r'<dl class="links"><dt>.*?<b>([^ ]+?)</b>.*?</dt><dd>(.*?)'
-     r'<span class="typ">(.*?)</span></dd></dl>',
-     r'\n.IP "\1(3)"\n\2 \3\n', 0),
-    # # With C++11 tag
-    (r'<dl class="links"><dt>.*?<b>([^ ]+?) <b class="C_cpp11" '
-     r'title="(.+?)">\W*</b>.*?</dt><dd>(.*?)'
-     r'<span class="typ">(.*?)</span></dd></dl>',
-     r'\n.IP "\1(3) [\2]"\n\3 \4\n', 0),
+    # Without C++11 tag
+    (r'<dl class="links"><dt><a href="[^"]*"><b>([^ ]+?)</b></a></dt><dd>'
+     r'([^<]*?)<span class="typ">\s*\(([^<]*?)\n?\)</span></dd></dl>',
+     r'\n.IP "\1(3)"\n\2 (\3)\n', re.S),
+    # With C++11 tag
+    (r'<dl class="links"><dt><a href="[^"]*"><b>([^ ]+?) <b class="C_cpp11" '
+     r'title="(.+?)"></b></b></a></dt><dd>'
+     r'([^<]*?)<span class="typ">\s*\((.*?)\n?\)</span></dd></dl>',
+     r'\n.IP "\1(3) [\2]"\n\3 (\4)\n', re.S),
     # Footer
     (r'<div id="CH_bb">.*$',
      r'\n.SE\n.SH "REFERENCE"\n'
      r'cplusplus.com, 2000-2015 - All rights reserved.', re.S),
     # C++ version tag
-    (r'<div title="(C\+\+..)"[^>]*>', r'.sp\n\1\n', 0),
+    (r'<div.+?title="(C\+\+..)"[^>]*>', r'.sp\n\1\n', 0),
     # 'br' tag
-    (r'<br>', r'\n.br\n', 0),
+    (r'<br/>', r'\n.br\n', 0),
     (r'\n.br\n.br\n', r'\n.sp\n', 0),
     # 'dd' 'dt' tag
     (r'<dt>(.+?)</dt>\s*<dd>(.+?)</dd>', r'.IP "\1"\n\2\n', re.S),
@@ -130,9 +130,6 @@ rps = [
     (r'&amp;', r'&', 0),
     (r'&nbsp;', r' ', 0),
     (r'\\([^\^nE])', r'\\\\\1', 0),
-    #: vector::data SYNOPSIS section has \x0d separting two lines
-    ('\x0d([^)])', r'\n.br\n\1', 0),
-    ('\x0d', r'', 0),
     (r'>/">', r'', 0),
     (r'/">', r'', 0),
     # Remove empty lines
@@ -142,6 +139,13 @@ rps = [
     (r'\\n', r'\en', 0),
 ]
 
+def escape_pre_section(table):
+    """Escape <pre> seciton in table."""
+    def replace_newline(g):
+        return g.group(1).replace('\n', '\n.br\n')
+
+    return re.sub('<pre.*?>(.*?)</pre>', replace_newline, table, flags=re.S)
+
 
 def html2groff(data, name):
     """Convert HTML text from cplusplus.com to Groff-formated text."""
@@ -151,17 +155,17 @@ def html2groff(data, name):
     except ValueError:
         pass
 
-    # Replace all
+    # Pre replace all
     for rp in pre_rps:
         data = re.compile(rp[0], rp[2]).sub(rp[1], data)
 
     for table in re.findall(r'<table.*?>.*?</table>', data, re.S):
-        tbl = parse_table(table)
+        tbl = parse_table(escape_pre_section(table))
         # Escape column with '.' as prefix
         tbl = re.compile(r'T{\n(\..*?)\nT}', re.S).sub(r'T{\n\E \1\nT}', tbl)
         data = data.replace(table, tbl)
 
-    # Pre replace all
+    # Replace all
     for rp in rps:
         data = re.compile(rp[0], rp[2]).sub(rp[1], data)
 
