@@ -93,6 +93,7 @@ rps = [
     # Remove tags
     (r'<span class="edit.*?">.*?</span> ?', r'', re.S),
     (r'&#91;edit&#93;', r'', re.S),
+    (r'\[edit\]', r'', re.S),
     (r'<div id="siteSub">.*?</div>', r'', 0),
     (r'<div id="contentSub">.*?</div>', r'', 0),
     (r'<table class="toc" id="toc"[^>]*>.*?</table>', r'', re.S),
@@ -143,7 +144,7 @@ rps = [
     (r'<div class="t-li2">(.*?)</div>',
      r'\n.RS\n\1\n.RE\n.sp\n', re.S),
     # 'br' tag
-    (r'<br>', r'\n.br\n', 0),
+    (r'<br/>', r'\n.br\n', 0),
     (r'\n.br\n.br\n', r'\n.sp\n', 0),
     # 'dd' 'dt' tag
     (r'<dt>(.+?)</dt>\s*<dd>(.+?)</dd>', r'\n.IP "\1"\n\2\n', re.S),
@@ -194,7 +195,7 @@ def html2groff(data, name):
     except ValueError:
         pass
 
-    # Remove non prinatable characters
+    # Remove non-printable characters
     data = ''.join([x for x in data if x in string.printable])
 
     for table in re.findall(
@@ -209,7 +210,7 @@ def html2groff(data, name):
     for rp in rps:
         data = re.compile(rp[0], rp[2]).sub(rp[1], data)
 
-    # Remove non prinatable characters
+    # Remove non-printable characters
     data = ''.join([x for x in data if x in string.printable])
 
     # Upper case all section headers
@@ -285,7 +286,7 @@ def html2groff(data, name):
                                   content)
                 data = data.replace(content, content2)
 
-    # Remove uneeded pseudo macro
+    # Remove unneeded pseudo macro
     data = re.sub('(?:\n.SE|.IBEGIN.*?\n|\n.IEND)', '', data)
 
     # Replace all macros
