@@ -22,8 +22,6 @@
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-
-
 import gzip
 import importlib
 import os
@@ -41,12 +39,13 @@ from cppman.crawler import Crawler
 
 class Cppman(Crawler):
     """Manage cpp man pages, indexes"""
-    def __init__(self, forced=False):
+    def __init__(self, forced=False, force_columns=-1):
         Crawler.__init__(self)
         self.results = set()
         self.forced = forced
         self.success_count = None
         self.failure_count = None
+        self.force_columns = force_columns
 
         self.blacklist = [
         ]
@@ -63,7 +62,7 @@ class Cppman(Crawler):
         return name
 
     def rebuild_index(self):
-        """Rebuild index database from cplusplus.com."""
+        """Rebuild index database from cplusplus.com and cppreference.com."""
         try:
             os.remove(environ.index_db_re)
         except:
@@ -86,13 +85,13 @@ class Cppman(Crawler):
                 self.insert_index('cplusplus.com', name, url)
             self.db_conn.commit()
 
-            # Rename dumplicate entries
-            dumplicates = self.db_cursor.execute('SELECT name, COUNT(name) '
-                                                 'AS NON '
-                                                 'FROM "cplusplus.com" '
-                                                 'GROUP BY NAME '
-                                                 'HAVING (NON > 1)').fetchall()
-            for name, num in dumplicates:
+            # Rename duplicate entries
+            duplicates = self.db_cursor.execute('SELECT name, COUNT(name) '
+                                                'AS NON '
+                                                'FROM "cplusplus.com" '
+                                                'GROUP BY NAME '
+                                                'HAVING (NON > 1)').fetchall()
+            for name, num in duplicates:
                 dump = self.db_cursor.execute('SELECT name, url FROM '
                                               '"cplusplus.com" WHERE name="%s"'
                                               % name).fetchall()
@@ -266,19 +265,20 @@ class Cppman(Crawler):
         finally:
             conn.close()
 
-        page_name = page_name.replace('/', '_')
-        if self.forced or page_name + '.3.gz' not in avail:
+        page_filename = self.get_normalized_page_name(page_name)
+        if self.forced or page_filename + '.3.gz' not in avail:
             self.cache_man_page(environ.source, url, page_name)
 
-        pager = environ.pager if sys.stdout.isatty() else environ.renderer
+        pager_type = environ.pager if sys.stdout.isatty() else 'pipe'
 
         # Call viewer
+        columns = (util.get_width() if self.force_columns == -1 else
+                   self.force_columns)
         pid = os.fork()
         if pid == 0:
-            os.execl('/bin/sh', '/bin/sh', pager,
+            os.execl('/bin/sh', '/bin/sh', environ.pager_script, pager_type,
                      self.get_page_path(environ.source, page_name),
-                     str(util.get_width()), environ.pager_config,
-                     page_name)
+                     str(columns), environ.pager_config, page_name)
         return pid
 
     def find(self, pattern):
@@ -313,5 +313,9 @@ class Cppman(Crawler):
         cmd = 'mandb %s' % (' -q' if quiet else '')
         subprocess.Popen(cmd, shell=True).wait()
 
+    def get_normalized_page_name(self, name):
+        return name.replace('/', '_')
+
     def get_page_path(self, source, name):
+        name = self.get_normalized_page_name(name)
         return os.path.join(environ.man_dir, source, name + '.3.gz')
